@@ -373,7 +373,7 @@ class Sequential():
                         if live_stats == 2 or live_stats == -1:
                             axs2.cla()
                             
-                            axs2.scatter(self.train_inputs[:,0], self.train_inputs[:,1], c=self.train_outputs[:,0], cmap="coolwarm")
+                            axs2.scatter(self.train_inputs[:,0], self.train_inputs[:,1], c=self.train_outputs[:,:], cmap="coolwarm", alpha=1)
                             
                             figure2.canvas.draw()
                             figure2.canvas.flush_events()
@@ -419,7 +419,7 @@ class Sequential():
                         if live_stats == 2 or live_stats == -1:
                             axs2.cla()
                             
-                            axs2.scatter(self.train_inputs[:,0], self.train_inputs[:,1], c=self.train_outputs[:,0], cmap="coolwarm")
+                            axs2.scatter(self.train_inputs[:,0], self.train_inputs[:,1], c=self.train_outputs[:,:], cmap="coolwarm", alpha=1)
                             
                             figure2.canvas.draw()
                             figure2.canvas.flush_events()
